# torskel
Python package with skeleton of the base Tornado application.

Contains basic functions for logging, asynchronous redis, support for reactJS and asynchronous http request
Only Python 3.5+

For redis support  - your need install aioredis >=1.0.0
For reactJs support your need install jinja2

For more information see examples